@@ -1,23 +1,26 @@
 <?php
-// $Id: chat.php,v 1.7.2.1 2002/11/26 17:23:15 nanasess Exp $
+// $Id: chat.php,v 1.1.1.2 2003/01/09 11:20:57 nanasess Exp $
 session_name("CHATSESS");
 session_start();
-if ($_SESSION["cook"] == 1) {
+if (isset($_SESSION["cook"]) && $_SESSION["cook"] == 1) {
   session_set_cookie_params(60*60*24*30*3+time(), "./");
 } else {
   session_set_cookie_params(0, "./");
 }
 $include_path = "./include";
-include $include_path . "/chat.inc";
+require_once $include_path . "/chat.inc";
 $nChat = new myChatPref;
 $db = new myDB_Sql;
 $myChat = new Chat;
 ?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
-<html>
+<?xml version="1.0" encoding="EUC-JP" ?>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
+<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja">
 <head>
 <title><?php $nChat->PrintTitle(); ?></title>
 <meta http-equiv="Content-Type" content="text/html; charset=EUC-JP" />
+<meta http-equiv="Content-Style-Type" content="text/css" />
+<link rel="stylesheet" type="text/css" href="basic.css" />
 <?php
 if (isset($_GET["W"])) { // ⡼ɤϥɤʤ
   ;
@@ -30,29 +33,29 @@ if (isset($_GET["W"])) { // ⡼ɤϥɤʤ
   $myChat->AutoReloadLog();
 }
 print("</head>\n");
-$nChat->PrintBody();
-print("<font size=\"2\">");
-$db->query("BEGIN");
-$myChat->ReloadLog();
-$myChat->Sanka();
-$db->query("COMMIT");
-print("</font>\n");
+print("<body>\n");
+print("<div class=\"size10px\">");
+$db->dbObj->query("BEGIN");
+$myChat->reloadLog();
+$myChat->sanka();
+$db->dbObj->query("COMMIT");
+print("</div>\n");
 if (isset($_GET["out"])) {
-	$myChat->OutLog();
+	$myChat->outLog();
     if (empty($_SESSION["R"])) {
         $_SESSION["R"] = "";
     }
 }
 
 if ($_POST["chat"] != "") {
-  $myChat->WriteLog(); // 񤭹
+  $myChat->writeLog(); // 񤭹
 } else {
-  $myChat->Reload();
+  $myChat->reload();
 }
-$db->query("BEGIN");
-$myChat->GetLogData();
-$myChat->PrintFooter();
-$db->query("COMMIT");
+$db->dbObj->query("BEGIN");
+$myChat->getLogData();
+$myChat->printFooter();
+$db->dbObj->query("COMMIT");
 ?>
 </body>
 </html>
